Imports System.ComponentModel

Public Enum ValMode
    AlphaNum
    Num
    Alpha
End Enum

Public Class CustomTextBox
    Inherits System.Windows.Forms.TextBox

    Dim _mandatory As Boolean
    Dim _FocusColor, _BlurColor As Color
    Dim _valuetype As ValMode
    Dim _minvalue As String = ""
    Dim _maxvalue As String = ""
    Dim _errmsg As String = "Mandatory Field"
    Dim _author As String = "Jayandra W. Patil"
#Region " Windows Form Designer generated code "

    Public Sub New()
        MyBase.New()

        'This call is required by the Windows Form Designer.
        InitializeComponent()
        'Add any initialization after the InitializeComponent() call

    End Sub

    'UserControl1 overrides dispose to clean up the component list.
    Protected Overloads Overrides Sub Dispose(ByVal disposing As Boolean)
        If disposing Then
            If Not (components Is Nothing) Then
                components.Dispose()
            End If
        End If
        MyBase.Dispose(disposing)
    End Sub

    'Required by the Windows Form Designer
    Private components As System.ComponentModel.IContainer

    'NOTE: The following procedure is required by the Windows Form Designer
    'It can be modified using the Windows Form Designer.  
    'Do not modify it using the code editor.
    Friend WithEvents ErrorProvider1 As System.Windows.Forms.ErrorProvider
    <System.Diagnostics.DebuggerStepThrough()> Private Sub InitializeComponent()
        Me.ErrorProvider1 = New System.Windows.Forms.ErrorProvider()
        '
        'CustomTextBox
        '

    End Sub

#End Region

    Private Sub CustomTextBox_KeyPress(ByVal sender As Object, ByVal e As System.Windows.Forms.KeyPressEventArgs) Handles MyBase.KeyPress
        Dim KeyAscii As Integer
        KeyAscii = Asc(e.KeyChar)
        If ValueType = ValMode.Num Then
            Select Case KeyAscii
                Case 48 To 57, 8, 13
                Case 45
                    If InStr(Me.Text, "-") <> 0 Then
                        KeyAscii = 0
                    End If
                    If Me.SelectionStart <> 0 Then
                        KeyAscii = 0
                    End If
                Case 46
                    If InStr(Me.Text, ".") <> 0 Then
                        KeyAscii = 0
                    End If
                Case Else
                    KeyAscii = 0
            End Select
        ElseIf ValueType = ValMode.Alpha Then
            Select Case KeyAscii
                Case 65 To 90, 97 To 122, 8, 13

                Case Else
                    KeyAscii = 0
            End Select
        End If

        If KeyAscii = 0 Then
            e.Handled = True
        Else
            e.Handled = False
        End If

    End Sub

    <Description("Indicates whether the control is mandatory")> Property Mandatory() As Boolean
        Get
            Mandatory = _mandatory
        End Get
        Set(ByVal Value As Boolean)
            _mandatory = Value
        End Set
    End Property

    <Description("Indicates the Type of Data in the control")> Property ValueType() As ValMode
        Get
            ValueType = _valuetype
        End Get
        Set(ByVal Value As ValMode)
            _valuetype = Value
        End Set
    End Property

    <Description("Indicates the Color of control when it receives the Focus")> Property FocusColor() As Color
        Get
            FocusColor = _FocusColor
        End Get
        Set(ByVal Value As Color)
            _FocusColor = Value
        End Set
    End Property

    <Description("Indicates the Color of control when it looses the Focus")> Property BlurColor() As Color
        Get
            BlurColor = _BlurColor
        End Get
        Set(ByVal Value As Color)
            _BlurColor = Value
        End Set
    End Property

    <Description("Indicates the Error Message for the control if it Fails the Mandatory Validation")> Property ErrorMessage() As String
        Get
            Return _errmsg
        End Get
        Set(ByVal Value As String)
            _errmsg = Value
        End Set
    End Property

    <Description("Indicates the Author of this Control")> ReadOnly Property Author() As String
        Get
            Return _author
        End Get
    End Property

    <Description("Indicates the Min. Value of control in case of Numeric Values")> Property MinValue() As String
        Get
            Return _minvalue
        End Get
        Set(ByVal Value As String)
            _minvalue = Value
        End Set
    End Property

    <Description("Indicates the Max Value of control in case of Numeric Values")> Property MaxValue() As String
        Get
            Return _maxvalue
        End Get
        Set(ByVal Value As String)
            _maxvalue = Value
        End Set
    End Property

    Private Sub CustomTextBox_Enter(ByVal sender As Object, ByVal e As System.EventArgs) Handles MyBase.Enter
        Me.BackColor = FocusColor
    End Sub

    Private Sub CustomTextBox_Leave(ByVal sender As Object, ByVal e As System.EventArgs) Handles MyBase.Leave
        Dim _valchk As Boolean

	Me.BackColor = BlurColor
        If Trim(Me.Text).Length = 0 And _mandatory Then
            Me.Focus()
            If _errmsg <> "" Then
                ErrorProvider1.SetError(Me, _errmsg)
            End If
        Else
            ErrorProvider1.SetError(Me, "")
            If ValueType = ValMode.Num Then
                If Me.Text <> "" Then
                    If Me.Text.Length = 1 And (InStr(Me.Text, ".") <> 0 Or InStr(Me.Text, "-") <> 0) Then
                        Me.Focus()
                        ErrorProvider1.SetError(Me, "Invalid Input")
                    Else
                        If _minvalue.Trim <> "" Then
                            If CType(Me.Text, Single) < CType(_minvalue, Single) Then
                                _valchk = True
                            End If
                        End If
                        If _maxvalue.Trim <> "" Then
                            If CType(Me.Text, Single) > CType(_maxvalue, Single) Then
                                _valchk = True
                            End If
                        End If

                        If _valchk Then
                            Me.Focus()
                            ErrorProvider1.SetError(Me, "Value out of set limits")
                        Else
                            ErrorProvider1.SetError(Me, "")
                        End If
                    End If
                End If
            End If
        End If
    End Sub
End Class
